# gravify

**gravify** is a simple package to generate
[Gravatar](https://en.gravatar.com/) URLs. :link:

```py
>>> user = Gravatar("example@example.com")
>>> user.url
'https://www.gravatar.com/avatar/23463b99b62a72f26ed677cc556c44e8'
```

[![Downloads](https://pepy.tech/badge/gravify)](https://pepy.tech/project/gravify)
[![Supported Versions](https://img.shields.io/pypi/pyversions/gravify.svg)](https://pypi.org/project/gravify)
[![Testing](https://img.shields.io/github/workflow/status/bsoyka/gravify/Python%20package?label=tests)](https://github.com/bsoyka/gravify/actions?query=workflow%3A%22Python+package%22)
[![License](https://img.shields.io/pypi/l/gravify)](https://github.com/bsoyka/gravify/blob/master/LICENSE)
[![Version](https://img.shields.io/pypi/v/gravify?label=latest)](https://pypi.org/project/gravify)

## Installation

gravify is available on PyPI:

```sh
$ pip install gravify
```

gravify officially supports Python 3.5+.

## API Reference
See [Read the Docs](https://gravify.readthedocs.io/) for gravify's documentation.
